**************************
PRISMH.CORE Change History
**************************


0.1.1 (2015-05-29)
==================

* Fixed an issue where unprompted fields in Forms weren't being considered when
  verifying field coverage.


0.1.0 (2015-05-29)
==================

* Initial release for review.

